/* This file is part of the KDE project
 *
 * Copyright (C) 2003 Koos Vriezen <koos.vriezen@xs4all.nl>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef KMPLAYERSOURCE_H
#define KMPLAYERSOURCE_H

#include <qobject.h>
#include <qstring.h>

class KMPlayer;

class KMPlayerSource : public QObject {
    Q_OBJECT
public:
    KMPlayerSource (KMPlayer * player);
    virtual ~KMPlayerSource ();
    virtual void init ();
    virtual bool processOutput (const QString & line);
    virtual QString filterOptions ();
    virtual bool hasLength ();
    virtual bool isSeekable ();
    int width () const { return m_width; }
    int height () const { return m_height; }
    int length () const { return m_length; }
    float aspect () const { return m_aspect; }
    void setWidth (int w) { m_width = w; }
    void setHeight (int h) { m_height = h; }
    void setAspect (float a) { m_aspect = a; }
    void setLength (int len) { m_length = len; }
    virtual QString recordCommand ();
public slots:
    virtual void activate () = 0;
    virtual void deactivate () = 0;
    virtual void play () = 0;
protected:
    KMPlayer * m_player;
    QString m_recordCommand;
    bool m_identified;
private:
    int m_width;
    int m_height;
    float m_aspect;
    int m_length;
};

#endif
